==> core-react-0.8.0.tgz: package/es/notification/Notification.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import marked from 'marked';
import cx from 'classnames';
import Dialog from '../dialog/Dialog';
import DialogBody from '../dialog/DialogBody';
import DialogButtons from '../dialog/DialogButtons';
import DialogHeader from '../dialog/DialogHeader';


var Notification = /*#__PURE__*/function (_React$Component) {
  _inherits(Notification, _React$Component);

  function Notification() {
    var _this;

    _classCallCheck(this, Notification);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Notification).call(this));

    _defineProperty(_assertThisInitialized(_this), "handleDialogClose", function () {
      var _this$props, _this$props$onClose;

      _this.setState({
        isOpen: false
      });

      (_this$props = _this.props) === null || _this$props === void 0 ? void 0 : (_this$props$onClose = _this$props.onClose) === null || _this$props$onClose === void 0 ? void 0 : _this$props$onClose.call(_this$props);
    });

    _this.state = {
      isOpen: true
    };
    return _this;
  }

  _createClass(Notification, [{
    key: "render",
    value: function render() {
      var _this$props2 = this.props,
          backdrop = _this$props2.backdrop,
          lock = _this$props2.lock,
          type = _this$props2.type,
          options = _this$props2.options,
          acceptLabel = _this$props2.acceptLabel,
          message = _this$props2.message,
          autoClose = _this$props2.autoClose,
          duration = _this$props2.duration;
      return React.createElement("div", null, !!this.state.isOpen && React.createElement(Dialog, {
        type: "notification",
        onClose: this.handleDialogClose,
        backdrop: backdrop,
        lock: lock,
        autoClose: autoClose,
        duration: duration
      }, React.createElement(DialogHeader, {
        type: type,
        icon: options === null || options === void 0 ? void 0 : options.icon
      }), React.createElement(DialogBody, null, React.createElement("div", {
        className: cx("".concat("waui", "-dialog__body-markdown"), _defineProperty({}, "".concat("waui", "-dialog__body-markdown_success"), type === 'success')),
        dangerouslySetInnerHTML: {
          __html: marked(message)
        }
      })), !!acceptLabel && React.createElement(DialogButtons, _extends({
        type: type,
        focused: options === null || options === void 0 ? void 0 : options.focused,
        acceptLabel: acceptLabel
      }, options))));
    }
  }]);

  return Notification;
}(React.Component);

export default Notification;

==> core-react-0.8.2.tgz: package/es/notification/Notification.js <==
function _typeof(obj) { "@babel/helpers - typeof"; if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") { _typeof = function _typeof(obj) { return typeof obj; }; } else { _typeof = function _typeof(obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; }; } return _typeof(obj); }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

function _possibleConstructorReturn(self, call) { if (call && (_typeof(call) === "object" || typeof call === "function")) { return call; } return _assertThisInitialized(self); }

function _getPrototypeOf(o) { _getPrototypeOf = Object.setPrototypeOf ? Object.getPrototypeOf : function _getPrototypeOf(o) { return o.__proto__ || Object.getPrototypeOf(o); }; return _getPrototypeOf(o); }

function _assertThisInitialized(self) { if (self === void 0) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function"); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, writable: true, configurable: true } }); if (superClass) _setPrototypeOf(subClass, superClass); }

function _setPrototypeOf(o, p) { _setPrototypeOf = Object.setPrototypeOf || function _setPrototypeOf(o, p) { o.__proto__ = p; return o; }; return _setPrototypeOf(o, p); }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

import React from 'react';
import marked from 'marked';
import cx from 'classnames';
import Dialog from '../dialog/Dialog';
import DialogBody from '../dialog/DialogBody';
import DialogButtons from '../dialog/DialogButtons';
import DialogHeader from '../dialog/DialogHeader';


var Notification = /*#__PURE__*/function (_React$Component) {
  _inherits(Notification, _React$Component);

  function Notification() {
    var _this;

    _classCallCheck(this, Notification);

    _this = _possibleConstructorReturn(this, _getPrototypeOf(Notification).call(this));

    _defineProperty(_assertThisInitialized(_this), "handleDialogClose", function () {
      var _this$props, _this$props$onClose;

      _this.setState({
        isOpen: false
      });

      (_this$props = _this.props) === null || _this$props === void 0 ? void 0 : (_this$props$onClose = _this$props.onClose) === null || _this$props$onClose === void 0 ? void 0 : _this$props$onClose.call(_this$props);
    });

    _this.state = {
      isOpen: true
    };
    return _this;
  }

  _createClass(Notification, [{
    key: "render",
    value: function render() {
      var _this$props2 = this.props,
          backdrop = _this$props2.backdrop,
          lock = _this$props2.lock,
          type = _this$props2.type,
          options = _this$props2.options,
          acceptLabel = _this$props2.acceptLabel,
          message = _this$props2.message,
          autoClose = _this$props2.autoClose,
          duration = _this$props2.duration;
      return (/*#__PURE__*/React.createElement("div", null, !!this.state.isOpen && /*#__PURE__*/React.createElement(Dialog, {
          type: "notification",
          onClose: this.handleDialogClose,
          backdrop: backdrop,
          lock: lock,
          autoClose: autoClose,
          duration: duration
        }, /*#__PURE__*/React.createElement(DialogHeader, {
          type: type,
          icon: options === null || options === void 0 ? void 0 : options.icon
        }), /*#__PURE__*/React.createElement(DialogBody, null, /*#__PURE__*/React.createElement("div", {
          className: cx("".concat("waui", "-dialog__body-markdown"), _defineProperty({}, "".concat("waui", "-dialog__body-markdown_success"), type === 'success')),
          dangerouslySetInnerHTML: {
            __html: marked(message)
          }
        })), !!acceptLabel && /*#__PURE__*/React.createElement(DialogButtons, _extends({
          type: type,
          focused: options === null || options === void 0 ? void 0 : options.focused,
          acceptLabel: acceptLabel
        }, options))))
      );
    }
  }]);

  return Notification;
}(React.Component);

export default Notification;
